/*
 * Java-Modell des Datenkatalogs.
 * Copyright (C) 2016 BitCtrl Systems GmbH 
 * 
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for more
 * details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA.
 *
 * Contact Information:
 * BitCtrl Systems GmbH
 * Weißenfelser Straße 67
 * 04229 Leipzig
 * Phone: +49 341-490670
 * mailto: info@bitctrl.de
 */

package de.bsvrz.sys.funclib.bitctrl.modell.bitctrleclipse.attribute;

import java.util.*;

import com.bitctrl.beans.*;

import de.bsvrz.dav.daf.main.*;
import de.bsvrz.dav.daf.main.config.*;
import de.bsvrz.sys.funclib.bitctrl.modell.*;
import de.bsvrz.sys.funclib.bitctrl.modell.annotation.*;
import de.bsvrz.sys.funclib.bitctrl.modell.att.*;
import de.bsvrz.sys.funclib.bitctrl.modell.impl.*;

/**
Beschreibt einen Linienstil.
<p>
Die Zahlenwerte der Linienstile sind so gewählt, dass sie den SWT-Konstanten in Eclipse 3.5
					entsprechen.
</p>
* @author BitCtrl Systems GmbH, M2T
 * @version Gültig seit KB-Version 1
 */
@Wertebereich(
	minimum = 1L,
	maximum = 5L,
	einheit = ""
)
@Defaultwert(wert = "1")
public class AttLinienStil extends Zahl<		Integer
> {
	
	private static final long serialVersionUID = 1L;
	
	/**
	 * Der minimale Wert des Attributs.
	 *
	 * @deprecated neu: {@link WerteBereich#getWerteBereich(Class)} und {@link #getWerteBereich()}
	 */
	@Deprecated
	public static final 		Integer
	 MIN_VALUE =
				Integer
		.valueOf("1");
	
	/**
	 * Der maximale Wert des Attributs.
	 *
	 * @deprecated neu: {@link WerteBereich#getWerteBereich(Class)} und {@link #getWerteBereich()}
	 */
	@Deprecated
	public static final 		Integer
	 MAX_VALUE =
				Integer
		.valueOf("5");
	
	/**
	 * Die Einheit.
	 *
	 * @deprecated neu: {@link WerteBereich#getWerteBereich(Class)} und {@link #getWerteBereich()}
	 */
	@Deprecated
	public static final String EINHEIT = "";
	
	/**
	
	<p>
	
	</p>
	*/
	public static final AttLinienStil ZUSTAND_1_DURCHGEZOGEN = new AttLinienStil("Durchgezogen", 		Integer
	.valueOf("1"));

	/**
	
	<p>
	
	</p>
	*/
	public static final AttLinienStil ZUSTAND_2_GESTRICHELT = new AttLinienStil("Gestrichelt", 		Integer
	.valueOf("2"));

	/**
	
	<p>
	
	</p>
	*/
	public static final AttLinienStil ZUSTAND_3_GEPUNKTED = new AttLinienStil("Gepunkted", 		Integer
	.valueOf("3"));

	/**
	
	<p>
	
	</p>
	*/
	public static final AttLinienStil ZUSTAND_4_STRICH_PUNKT = new AttLinienStil("Strich-Punkt", 		Integer
	.valueOf("4"));

	/**
	
	<p>
	
	</p>
	*/
	public static final AttLinienStil ZUSTAND_5_STRICH_PUNKT_PUNKT = new AttLinienStil("Strich-Punkt-Punkt", 		Integer
	.valueOf("5"));

	/**
	 * Gibt den Zustand zu einer Zahl zurück oder <code>null</code>, wenn die
	 * Zahl keinen Zustand repräsentiert.
	 *
	 * @param value ein Zahlenwert
	 * @return der Zustand zu dem Zahlenwert oder <code>null</code>, wenn die
	 * Zahl keine Entsprechnung als Zustand besitzt.
	 */
	public static AttLinienStil getZustand(final 		Integer
	 value) {
		for (AttLinienStil e : getZustaende()) {
			if (e.getValue().equals(value)) {
				return e;
			}
		}
		return null;
	}
	
	/**
	 * Gibt den Zustand zu einem Zustandsnamen zurück oder <code>null</code>,
	 * wenn kein Zustand einen solchen Namen hat.
	 * 
	 * @param value
	 *            der Zustandsname
	 * @return der Zustand zu dem Zustandsnamen oder <code>null</code>, wenn
	 *         kein Zustand einen solchen Namen hat.
	 */
	public static AttLinienStil getZustand(final String value) {
		for (AttLinienStil e : getZustaende()) {
			if (e.toString().equals(value)) {
				return e;
			}
		}
		return null;
	}
	
	/**
	 * Gibt alle Zustände zurück, die das Attribut besitzen kann.
	 *
	 * @return alle Zustände die das Attribut annehmen kann.
	 */
	public static List<AttLinienStil> getZustaende() {
		List<AttLinienStil> list = new ArrayList<AttLinienStil>();
		list.add(ZUSTAND_1_DURCHGEZOGEN);
		list.add(ZUSTAND_2_GESTRICHELT);
		list.add(ZUSTAND_3_GEPUNKTED);
		list.add(ZUSTAND_4_STRICH_PUNKT);
		list.add(ZUSTAND_5_STRICH_PUNKT_PUNKT);
		return list;
	}	
	/**
	 * Erzeugte eine neues Attribut LinienStil.
	 *
	 * @param value der Wert der Zahl.
	 */
	public AttLinienStil(final 		Integer
	 value) {
		super(value);
	}
	
	private AttLinienStil(final String zustand, final 		Integer
	 value) {
		super(zustand, value);
	}
	
}
