/*
 * Java-Modell des Datenkatalogs.
 * Copyright (C) 2016 BitCtrl Systems GmbH 
 * 
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for more
 * details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA.
 *
 * Contact Information:
 * BitCtrl Systems GmbH
 * Weißenfelser Straße 67
 * 04229 Leipzig
 * Phone: +49 341-490670
 * mailto: info@bitctrl.de
 */

package de.bsvrz.sys.funclib.bitctrl.modell.tmbitctrltur.attribute;

import java.util.*;

import com.bitctrl.beans.*;

import de.bsvrz.dav.daf.main.*;
import de.bsvrz.dav.daf.main.config.*;
import de.bsvrz.sys.funclib.bitctrl.modell.*;
import de.bsvrz.sys.funclib.bitctrl.modell.annotation.*;
import de.bsvrz.sys.funclib.bitctrl.modell.att.*;
import de.bsvrz.sys.funclib.bitctrl.modell.impl.*;

/**
Definiert einen 32-Bit-Integertyp zur Darstellung der
					Anzahl von Stellplätzen.
<p>
Die Definition läßt bewußt negative Werte zu, da die
					Zwischenergebnisse bzw. die Rohwerte verschiedener Algorithmen auch
					negativ werden können. In Pilotprojekten und zur Verfeinerung der
					Parametrierung der Anlage müssen diese Werte auch archiviert und in
					Protokollen betrachtet werden können.
</p>
* @author BitCtrl Systems GmbH, M2T
 * @version Gültig seit KB-Version 1
 */
@Wertebereich(
	minimum = -20000L,
	maximum = 20000L,
	einheit = "Stellplaetze"
)
@Defaultwert(wert = "nicht ermittelbar")
public class AttTurStellplatzAnzahl extends Zahl<		Integer
> {
	
	private static final long serialVersionUID = 1L;
	
	/**
	 * Der minimale Wert des Attributs.
	 *
	 * @deprecated neu: {@link WerteBereich#getWerteBereich(Class)} und {@link #getWerteBereich()}
	 */
	@Deprecated
	public static final 		Integer
	 MIN_VALUE =
				Integer
		.valueOf("-20000");
	
	/**
	 * Der maximale Wert des Attributs.
	 *
	 * @deprecated neu: {@link WerteBereich#getWerteBereich(Class)} und {@link #getWerteBereich()}
	 */
	@Deprecated
	public static final 		Integer
	 MAX_VALUE =
				Integer
		.valueOf("20000");
	
	/**
	 * Die Einheit.
	 *
	 * @deprecated neu: {@link WerteBereich#getWerteBereich(Class)} und {@link #getWerteBereich()}
	 */
	@Deprecated
	public static final String EINHEIT = "Stellplaetze";
	
	/**
	Daten sind nicht ermittelbar (ist KEIN Fehler).
	<p>
	Wird gesetzt, wenn der entsprechende Wert nicht
								ermittelbar ist und eine Interpolation nicht sinnvoll möglich ist
								(z.B. ist die Anzahl belegter Stellplätze nicht möglich, wenn
								kein Initialwert vorgegeben wurde).
	</p>
	*/
	public static final AttTurStellplatzAnzahl ZUSTAND_40001N_NICHT_ERMITTELBAR = new AttTurStellplatzAnzahl("nicht ermittelbar", 		Integer
	.valueOf("-40001"));

	/**
	Daten sind fehlerhaft.
	<p>
	Wird gesetzt, wenn die Daten als fehlerhaft erkannt
								wurden.
	</p>
	*/
	public static final AttTurStellplatzAnzahl ZUSTAND_40002N_FEHLERHAFT = new AttTurStellplatzAnzahl("fehlerhaft", 		Integer
	.valueOf("-40002"));

	/**
	Daten nicht ermittelbar, da bereits Basiswerte
								fehlerhaft.
	<p>
	Wird gesetzt, wenn Daten, die zur Berechnung dieses
								Werts notwendig sind, bereits als fehlerhaft gekennzeichnet sind,
								oder wenn die Berechnung aus anderen Gründen (z.B. Nenner = 0 in
								der Berechnungsformel) nicht möglich war.
	</p>
	*/
	public static final AttTurStellplatzAnzahl ZUSTAND_40003N_NICHT_ERMITTELBAR_FEHLERHAFT = new AttTurStellplatzAnzahl("nicht ermittelbar/fehlerhaft", 		Integer
	.valueOf("-40003"));

	/**
	 * Gibt den Zustand zu einer Zahl zurück oder <code>null</code>, wenn die
	 * Zahl keinen Zustand repräsentiert.
	 *
	 * @param value ein Zahlenwert
	 * @return der Zustand zu dem Zahlenwert oder <code>null</code>, wenn die
	 * Zahl keine Entsprechnung als Zustand besitzt.
	 */
	public static AttTurStellplatzAnzahl getZustand(final 		Integer
	 value) {
		for (AttTurStellplatzAnzahl e : getZustaende()) {
			if (e.getValue().equals(value)) {
				return e;
			}
		}
		return null;
	}
	
	/**
	 * Gibt den Zustand zu einem Zustandsnamen zurück oder <code>null</code>,
	 * wenn kein Zustand einen solchen Namen hat.
	 * 
	 * @param value
	 *            der Zustandsname
	 * @return der Zustand zu dem Zustandsnamen oder <code>null</code>, wenn
	 *         kein Zustand einen solchen Namen hat.
	 */
	public static AttTurStellplatzAnzahl getZustand(final String value) {
		for (AttTurStellplatzAnzahl e : getZustaende()) {
			if (e.toString().equals(value)) {
				return e;
			}
		}
		return null;
	}
	
	/**
	 * Gibt alle Zustände zurück, die das Attribut besitzen kann.
	 *
	 * @return alle Zustände die das Attribut annehmen kann.
	 */
	public static List<AttTurStellplatzAnzahl> getZustaende() {
		List<AttTurStellplatzAnzahl> list = new ArrayList<AttTurStellplatzAnzahl>();
		list.add(ZUSTAND_40001N_NICHT_ERMITTELBAR);
		list.add(ZUSTAND_40002N_FEHLERHAFT);
		list.add(ZUSTAND_40003N_NICHT_ERMITTELBAR_FEHLERHAFT);
		return list;
	}	
	/**
	 * Erzeugte eine neues Attribut TuRStellplatzanzahl.
	 *
	 * @param value der Wert der Zahl.
	 */
	public AttTurStellplatzAnzahl(final 		Integer
	 value) {
		super(value);
	}
	
	private AttTurStellplatzAnzahl(final String zustand, final 		Integer
	 value) {
		super(zustand, value);
	}
	
}
