/*
 * Java-Modell des Datenkatalogs.
 * Copyright (C) 2016 BitCtrl Systems GmbH 
 * 
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for more
 * details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA.
 *
 * Contact Information:
 * BitCtrl Systems GmbH
 * Weißenfelser Straße 67
 * 04229 Leipzig
 * Phone: +49 341-490670
 * mailto: info@bitctrl.de
 */

package de.bsvrz.sys.funclib.bitctrl.modell.tmkextlsglobal.attribute;

import java.util.*;

import com.bitctrl.beans.*;

import de.bsvrz.dav.daf.main.*;
import de.bsvrz.dav.daf.main.config.*;
import de.bsvrz.sys.funclib.bitctrl.modell.*;
import de.bsvrz.sys.funclib.bitctrl.modell.annotation.*;
import de.bsvrz.sys.funclib.bitctrl.modell.att.*;
import de.bsvrz.sys.funclib.bitctrl.modell.impl.*;

/**
Fahrtrichtung (Nord&#47;Ost und&#47;oder Süd&#47;West.
<p>
In Streckenstationen, bzw. FGs, die beide
					Fahrtrichtungen betreffen, sind beide Richungen
					gleichzeitig gesetzt. Streckenstationen, bzw. FGs,
					die keine fahrbahnbezogenen Geräte enthalten, setzen
					keine Richtung. Für die Fahrtrichtung ist die
					Ausrichtung der gesamten Straße zwischen ihren
					Endpunkten entscheidend, nicht die Lage der Fahrbahn
					am betrachteten Querschnitt.
</p>
* @author BitCtrl Systems GmbH, M2T
 * @version Gültig seit KB-Version 1
 */
public class AttTlsFahrtrichtung extends Zahl<		Byte
> {
	
	private static final long serialVersionUID = 1L;
	
	
	/**
	
	<p>
	
	</p>
	*/
	public static final AttTlsFahrtrichtung ZUSTAND_0_NICHT_RICHTUNGSBEZOGEN = new AttTlsFahrtrichtung("nicht richtungsbezogen", 		Byte
	.valueOf("0"));

	/**
	
	<p>
	
	</p>
	*/
	public static final AttTlsFahrtrichtung ZUSTAND_1_NORD_BZW_OST = new AttTlsFahrtrichtung("Nord bzw. Ost", 		Byte
	.valueOf("1"));

	/**
	
	<p>
	
	</p>
	*/
	public static final AttTlsFahrtrichtung ZUSTAND_2_SUED_BZW_WEST = new AttTlsFahrtrichtung("Süd bzw. West", 		Byte
	.valueOf("2"));

	/**
	 * Gibt den Zustand zu einer Zahl zurück oder <code>null</code>, wenn die
	 * Zahl keinen Zustand repräsentiert.
	 *
	 * @param value ein Zahlenwert
	 * @return der Zustand zu dem Zahlenwert oder <code>null</code>, wenn die
	 * Zahl keine Entsprechnung als Zustand besitzt.
	 */
	public static AttTlsFahrtrichtung getZustand(final 		Byte
	 value) {
		for (AttTlsFahrtrichtung e : getZustaende()) {
			if (e.getValue().equals(value)) {
				return e;
			}
		}
		return null;
	}
	
	/**
	 * Gibt den Zustand zu einem Zustandsnamen zurück oder <code>null</code>,
	 * wenn kein Zustand einen solchen Namen hat.
	 * 
	 * @param value
	 *            der Zustandsname
	 * @return der Zustand zu dem Zustandsnamen oder <code>null</code>, wenn
	 *         kein Zustand einen solchen Namen hat.
	 */
	public static AttTlsFahrtrichtung getZustand(final String value) {
		for (AttTlsFahrtrichtung e : getZustaende()) {
			if (e.toString().equals(value)) {
				return e;
			}
		}
		return null;
	}
	
	/**
	 * Gibt alle Zustände zurück, die das Attribut besitzen kann.
	 *
	 * @return alle Zustände die das Attribut annehmen kann.
	 */
	public static List<AttTlsFahrtrichtung> getZustaende() {
		List<AttTlsFahrtrichtung> list = new ArrayList<AttTlsFahrtrichtung>();
		list.add(ZUSTAND_0_NICHT_RICHTUNGSBEZOGEN);
		list.add(ZUSTAND_1_NORD_BZW_OST);
		list.add(ZUSTAND_2_SUED_BZW_WEST);
		return list;
	}	
	/**
	 * Erzeugte eine neues Attribut TLSFahrtrichtung.
	 *
	 * @param value der Wert der Zahl.
	 */
	public AttTlsFahrtrichtung(final 		Byte
	 value) {
		super(value);
	}
	
	private AttTlsFahrtrichtung(final String zustand, final 		Byte
	 value) {
		super(zustand, value);
	}
	
}
