/*
 * Java-Modell des Datenkatalogs.
 * Copyright (C) 2016 BitCtrl Systems GmbH 
 * 
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for more
 * details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA.
 *
 * Contact Information:
 * BitCtrl Systems GmbH
 * Weißenfelser Straße 67
 * 04229 Leipzig
 * Phone: +49 341-490670
 * mailto: info@bitctrl.de
 */

package de.bsvrz.sys.funclib.bitctrl.modell.tmkextlsglobal.attribute;

import java.util.*;

import com.bitctrl.beans.*;

import de.bsvrz.dav.daf.main.*;
import de.bsvrz.dav.daf.main.config.*;
import de.bsvrz.sys.funclib.bitctrl.modell.*;
import de.bsvrz.sys.funclib.bitctrl.modell.annotation.*;
import de.bsvrz.sys.funclib.bitctrl.modell.att.*;
import de.bsvrz.sys.funclib.bitctrl.modell.impl.*;

/**
Taupunkttemperatur.
<p>
Taupunkttemperatur ist diejenige Temperatur, bei der
					die in der Umgebungsluft der Messstelle (am Ort der
					Temperatur und Feuchte-Sensorik) befindliche Feuchte
					zu kondensieren beginnt. Die Taupunkttemperatur ist
					aus der Temperatur und der relativen Feuchte der
					Luft zu bestimmen. Zur Bestimmung ist die in den
					neuesten ?betriebstechnischen Anforderungen für
					Glättemeldeanlagen? enthaltene Berechnungsvorschrift
					zu verwenden. Dieser Berechnungsvorschrift liegen
					auch die im Wetterdienst verwendeten
					Taupunkttabellen zugrunde.
</p>
* @author BitCtrl Systems GmbH, M2T
 * @version Gültig seit KB-Version 19
 */
@Wertebereich(
	minimum = -32768L,
	maximum = 32767L,
	skalierung = 0.1,
	einheit = "°C"
)
@Defaultwert(wert = "nicht ermittelbar")
public class AttTlsUfdTaupunkttemperatur extends Zahl<		Double
> {
	
	private static final long serialVersionUID = 1L;
	
	/**
	 * Der minimale Wert des Attributs.
	 *
	 * @deprecated neu: {@link WerteBereich#getWerteBereich(Class)} und {@link #getWerteBereich()}
	 */
	@Deprecated
	public static final 		Double
	 MIN_VALUE =
			(		double
			) (		Double
			.valueOf("-32768") * 		Double
			.valueOf("0.1"));	
	
	/**
	 * Der maximale Wert des Attributs.
	 *
	 * @deprecated neu: {@link WerteBereich#getWerteBereich(Class)} und {@link #getWerteBereich()}
	 */
	@Deprecated
	public static final 		Double
	 MAX_VALUE =
			(		double
			) (		Double
			.valueOf("32767") * 		Double
			.valueOf("0.1"));	
	
	/**
	 * Die Einheit.
	 *
	 * @deprecated neu: {@link WerteBereich#getWerteBereich(Class)} und {@link #getWerteBereich()}
	 */
	@Deprecated
	public static final String EINHEIT = "°C";
	
	/**
	
	<p>
	
	</p>
	*/
	public static final AttTlsUfdTaupunkttemperatur ZUSTAND_32767_NICHT_ERMITTELBAR = new AttTlsUfdTaupunkttemperatur("nicht ermittelbar", 		Double
	.valueOf("32767"));

	/**
	 * Gibt den Zustand zu einer Zahl zurück oder <code>null</code>, wenn die
	 * Zahl keinen Zustand repräsentiert.
	 *
	 * @param value ein Zahlenwert
	 * @return der Zustand zu dem Zahlenwert oder <code>null</code>, wenn die
	 * Zahl keine Entsprechnung als Zustand besitzt.
	 */
	public static AttTlsUfdTaupunkttemperatur getZustand(final 		Double
	 value) {
		for (AttTlsUfdTaupunkttemperatur e : getZustaende()) {
			if (e.getValue().equals(value)) {
				return e;
			}
		}
		return null;
	}
	
	/**
	 * Gibt den Zustand zu einem Zustandsnamen zurück oder <code>null</code>,
	 * wenn kein Zustand einen solchen Namen hat.
	 * 
	 * @param value
	 *            der Zustandsname
	 * @return der Zustand zu dem Zustandsnamen oder <code>null</code>, wenn
	 *         kein Zustand einen solchen Namen hat.
	 */
	public static AttTlsUfdTaupunkttemperatur getZustand(final String value) {
		for (AttTlsUfdTaupunkttemperatur e : getZustaende()) {
			if (e.toString().equals(value)) {
				return e;
			}
		}
		return null;
	}
	
	/**
	 * Gibt alle Zustände zurück, die das Attribut besitzen kann.
	 *
	 * @return alle Zustände die das Attribut annehmen kann.
	 */
	public static List<AttTlsUfdTaupunkttemperatur> getZustaende() {
		List<AttTlsUfdTaupunkttemperatur> list = new ArrayList<AttTlsUfdTaupunkttemperatur>();
		list.add(ZUSTAND_32767_NICHT_ERMITTELBAR);
		return list;
	}	
	/**
	 * Erzeugte eine neues Attribut TLSUfdTaupunkttemperatur.
	 *
	 * @param value der Wert der Zahl.
	 */
	public AttTlsUfdTaupunkttemperatur(final 		Double
	 value) {
		super(value);
	}
	
	private AttTlsUfdTaupunkttemperatur(final String zustand, final 		Double
	 value) {
		super(zustand, value);
	}
	
}
