/*
 * Java-Modell des Datenkatalogs.
 * Copyright (C) 2016 BitCtrl Systems GmbH 
 * 
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for more
 * details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA.
 *
 * Contact Information:
 * BitCtrl Systems GmbH
 * Weißenfelser Straße 67
 * 04229 Leipzig
 * Phone: +49 341-490670
 * mailto: info@bitctrl.de
 */

package de.bsvrz.sys.funclib.bitctrl.modell.tmkextlsglobal.objekte.impl;

import java.util.*;

import com.bitctrl.beans.*;

import de.bsvrz.dav.daf.main.*;
import de.bsvrz.dav.daf.main.config.*;
import de.bsvrz.sys.funclib.bitctrl.modell.*;
import de.bsvrz.sys.funclib.bitctrl.modell.annotation.*;
import de.bsvrz.sys.funclib.bitctrl.modell.att.*;
import de.bsvrz.sys.funclib.bitctrl.modell.impl.*;

/**
Kommunikationsrechner Inselbus "KRI2_B" gemäß Spezifikation PLaNT der ASFINAG.
<p>
TLS konformer Vermittlungsknoten (NICHT transparent beim Routing, also eigener
					Vermittlungsabschnitt), der zusätzlich die Eigenschaften eines SM hat, also zusätzliche EAK und DE
					zur Statusmeldung des KRI2_B Funktionszustandes bzw. der angeschlossenen Inselbusse.
</p>
* @author BitCtrl Systems GmbH, M2T
 * @version Gültig seit KB-Version 12
 */
public class Kri2BImpl extends AbstractSystemObjekt
	implements de.bsvrz.sys.funclib.bitctrl.modell.tmkextlsglobal.objekte.Kri2B { 

	/**
	 * Der Defaultkonstruktor wird für das Erzeugen des Systemobjekts über per
	 * Reflection-API benötigt.
	 */
	public Kri2BImpl() {
		// tut nix
	}
	
	/**
	 * Initialisierung.
	 * 
	 * @param objekt
	 *            ein beliebiges Systemobjekt.
	 * @param factory
	 *            die Fabrik, die das Systemobjekt angelegt hat.
	 */
	public Kri2BImpl(final SystemObject objekt, final ObjektFactory factory) {
		super(objekt, factory);
		
		if (!objekt.isOfType(getTyp().getPid())) {
			throw new IllegalArgumentException(
					"Systemobjekt ist kein KRI2_B.");
		}
	}
	
	@Override
	protected String doGetTypPid() {
		return PID;
	}
	
	/*
	 * Beginn Abschnitt Mengen
	 */
	
	private Collection<de.bsvrz.sys.funclib.bitctrl.modell.tmkextlsglobal.objekte.Eak> eak;
	
	public Collection<de.bsvrz.sys.funclib.bitctrl.modell.tmkextlsglobal.objekte.Eak> getEak() {
		if (eak == null) {
			final Collection<de.bsvrz.sys.funclib.bitctrl.modell.tmkextlsglobal.objekte.Eak> menge = new ArrayList<de.bsvrz.sys.funclib.bitctrl.modell.tmkextlsglobal.objekte.Eak>();
			ConfigurationObject ko = (ConfigurationObject) getSystemObject();
			if (ko.getObjectSet("Eak") == null) {
				// Die Menge ist nicht konfiguriert
				return null;
			}
			for (SystemObject so : ko.getObjectSet("Eak").getElements()) {
				menge.add((de.bsvrz.sys.funclib.bitctrl.modell.tmkextlsglobal.objekte.Eak) getObjektFactory().getModellobjekt(so));
			}
			eak = Collections.unmodifiableCollection(menge);
		}
		return eak;
	}
	private Collection<de.bsvrz.sys.funclib.bitctrl.modell.tmkextlsglobal.objekte.AnschlussPunkt> anschlussPunkteGeraet;
	
	public Collection<de.bsvrz.sys.funclib.bitctrl.modell.tmkextlsglobal.objekte.AnschlussPunkt> getAnschlussPunkteGeraet() {
		if (anschlussPunkteGeraet == null) {
			final Collection<de.bsvrz.sys.funclib.bitctrl.modell.tmkextlsglobal.objekte.AnschlussPunkt> menge = new ArrayList<de.bsvrz.sys.funclib.bitctrl.modell.tmkextlsglobal.objekte.AnschlussPunkt>();
			ConfigurationObject ko = (ConfigurationObject) getSystemObject();
			if (ko.getObjectSet("AnschlussPunkteGerät") == null) {
				// Die Menge ist nicht konfiguriert
				return null;
			}
			for (SystemObject so : ko.getObjectSet("AnschlussPunkteGerät").getElements()) {
				menge.add((de.bsvrz.sys.funclib.bitctrl.modell.tmkextlsglobal.objekte.AnschlussPunkt) getObjektFactory().getModellobjekt(so));
			}
			anschlussPunkteGeraet = Collections.unmodifiableCollection(menge);
		}
		return anschlussPunkteGeraet;
	}

	/*
	 * Ende Abschnitt Mengen
	 */

	/*
	 * Beginn Abschnitt Attributgruppen
	 */

	public de.bsvrz.sys.funclib.bitctrl.modell.tmkextlsglobal.konfigurationsdaten.KdGeraetTlsAehnlicheKommunikationsPartnerUmsetzungsModule getKdGeraetTlsAehnlicheKommunikationsPartnerUmsetzungsModule() {
		return getDatensatz(de.bsvrz.sys.funclib.bitctrl.modell.tmkextlsglobal.konfigurationsdaten.KdGeraetTlsAehnlicheKommunikationsPartnerUmsetzungsModule.class);
	}
	
	public de.bsvrz.sys.funclib.bitctrl.modell.metamodellglobal.konfigurationsdaten.KdDefaultParameterdatensaetze getKdDefaultParameterdatensaetze() {
		return getDatensatz(de.bsvrz.sys.funclib.bitctrl.modell.metamodellglobal.konfigurationsdaten.KdDefaultParameterdatensaetze.class);
	}
	
	public de.bsvrz.sys.funclib.bitctrl.modell.tmkextlsglobal.konfigurationsdaten.KdGeraetTlsAehnlicheKommunikationsPartner getKdGeraetTlsAehnlicheKommunikationsPartner() {
		return getDatensatz(de.bsvrz.sys.funclib.bitctrl.modell.tmkextlsglobal.konfigurationsdaten.KdGeraetTlsAehnlicheKommunikationsPartner.class);
	}
	
	public de.bsvrz.sys.funclib.bitctrl.modell.tmkextlsglobal.konfigurationsdaten.KdGeraetZustaendigkeit getKdGeraetZustaendigkeit() {
		return getDatensatz(de.bsvrz.sys.funclib.bitctrl.modell.tmkextlsglobal.konfigurationsdaten.KdGeraetZustaendigkeit.class);
	}
	
	public de.bsvrz.sys.funclib.bitctrl.modell.metamodellglobal.konfigurationsdaten.KdInfo getKdInfo() {
		return getDatensatz(de.bsvrz.sys.funclib.bitctrl.modell.metamodellglobal.konfigurationsdaten.KdInfo.class);
	}
	
	public de.bsvrz.sys.funclib.bitctrl.modell.metamodellglobal.konfigurationsdaten.KdAlternativeObjektbezeichnung getKdAlternativeObjektbezeichnung() {
		return getDatensatz(de.bsvrz.sys.funclib.bitctrl.modell.metamodellglobal.konfigurationsdaten.KdAlternativeObjektbezeichnung.class);
	}
	
	public de.bsvrz.sys.funclib.bitctrl.modell.tmkextlsglobal.konfigurationsdaten.KdGeraet getKdGeraet() {
		return getDatensatz(de.bsvrz.sys.funclib.bitctrl.modell.tmkextlsglobal.konfigurationsdaten.KdGeraet.class);
	}
	
	public de.bsvrz.sys.funclib.bitctrl.modell.tmilsetls.onlinedaten.OdOsi37Mitschnitt getOdOsi37Mitschnitt() {
		return getDatensatz(de.bsvrz.sys.funclib.bitctrl.modell.tmilsetls.onlinedaten.OdOsi37Mitschnitt.class); 
	}
	
	public de.bsvrz.sys.funclib.bitctrl.modell.tmilsetls.onlinedaten.OdOsi2Mitschnitt getOdOsi2Mitschnitt() {
		return getDatensatz(de.bsvrz.sys.funclib.bitctrl.modell.tmilsetls.onlinedaten.OdOsi2Mitschnitt.class); 
	}
	
	public de.bsvrz.sys.funclib.bitctrl.modell.tmkextlsglobal.onlinedaten.OdTlsEinzelTelegrammSenden getOdTlsEinzelTelegrammSenden() {
		return getDatensatz(de.bsvrz.sys.funclib.bitctrl.modell.tmkextlsglobal.onlinedaten.OdTlsEinzelTelegrammSenden.class); 
	}
	
	public de.bsvrz.sys.funclib.bitctrl.modell.tmilsetls.parameter.PdProtokollEinstellungenILSE getPdProtokollEinstellungenILSE() {
		return getDatensatz(de.bsvrz.sys.funclib.bitctrl.modell.tmilsetls.parameter.PdProtokollEinstellungenILSE.class);
	}
	
	public de.bsvrz.sys.funclib.bitctrl.modell.tmilsetls.parameter.PdUeberwachungsStatus getPdUeberwachungsStatus() {
		return getDatensatz(de.bsvrz.sys.funclib.bitctrl.modell.tmilsetls.parameter.PdUeberwachungsStatus.class);
	}
	
	public de.bsvrz.sys.funclib.bitctrl.modell.tmgeoreferenzierungglobal.konfigurationsdaten.KdPunktKoordinaten getKdPunktKoordinaten() {
		return getDatensatz(de.bsvrz.sys.funclib.bitctrl.modell.tmgeoreferenzierungglobal.konfigurationsdaten.KdPunktKoordinaten.class);
	}
	
	
	/*
	 * Ende Abschnitt Attributgruppen
	 */
	
	// Sonderfall Klasse AttributImpl
	 

}
