/*
 * Java-Modell des Datenkatalogs.
 * Copyright (C) 2016 BitCtrl Systems GmbH 
 * 
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for more
 * details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA.
 *
 * Contact Information:
 * BitCtrl Systems GmbH
 * Weißenfelser Straße 67
 * 04229 Leipzig
 * Phone: +49 341-490670
 * mailto: info@bitctrl.de
 */

package de.bsvrz.sys.funclib.bitctrl.modell.tmusv.attribute;

import java.util.*;

import com.bitctrl.beans.*;

import de.bsvrz.dav.daf.main.*;
import de.bsvrz.dav.daf.main.config.*;
import de.bsvrz.sys.funclib.bitctrl.modell.*;
import de.bsvrz.sys.funclib.bitctrl.modell.annotation.*;
import de.bsvrz.sys.funclib.bitctrl.modell.att.*;
import de.bsvrz.sys.funclib.bitctrl.modell.impl.*;

/**
Zustand der Kommunikation mit der USV-Anlage.
<p>

</p>
* @author BitCtrl Systems GmbH, M2T
 * @version Gültig seit KB-Version 1
 */
public class AttUsvKommunikationsZustand extends Zahl<		Byte
> {
	
	private static final long serialVersionUID = 1L;
	
	
	/**
	Daten sind nicht ermittelbar (ist KEIN Fehler).
	<p>
	Wird gesetzt, wenn der Kommunikationsstatus nicht bekannt ist.
	</p>
	*/
	public static final AttUsvKommunikationsZustand ZUSTAND_1N_NICHT_ERMITTELBAR = new AttUsvKommunikationsZustand("nicht ermittelbar", 		Byte
	.valueOf("-1"));

	/**
	Kommunikation mit USV-Anlage ist gestört.
	<p>
	
	</p>
	*/
	public static final AttUsvKommunikationsZustand ZUSTAND_0_KOMMUNIKATIONSSTOERUNG = new AttUsvKommunikationsZustand("Kommunikationsstörung", 		Byte
	.valueOf("0"));

	/**
	Kommunikation mit USV-Anlage ist in Ordnung.
	<p>
	
	</p>
	*/
	public static final AttUsvKommunikationsZustand ZUSTAND_1_IN_ORDNUNG = new AttUsvKommunikationsZustand("in Ordnung", 		Byte
	.valueOf("1"));

	/**
	 * Gibt den Zustand zu einer Zahl zurück oder <code>null</code>, wenn die
	 * Zahl keinen Zustand repräsentiert.
	 *
	 * @param value ein Zahlenwert
	 * @return der Zustand zu dem Zahlenwert oder <code>null</code>, wenn die
	 * Zahl keine Entsprechnung als Zustand besitzt.
	 */
	public static AttUsvKommunikationsZustand getZustand(final 		Byte
	 value) {
		for (AttUsvKommunikationsZustand e : getZustaende()) {
			if (e.getValue().equals(value)) {
				return e;
			}
		}
		return null;
	}
	
	/**
	 * Gibt den Zustand zu einem Zustandsnamen zurück oder <code>null</code>,
	 * wenn kein Zustand einen solchen Namen hat.
	 * 
	 * @param value
	 *            der Zustandsname
	 * @return der Zustand zu dem Zustandsnamen oder <code>null</code>, wenn
	 *         kein Zustand einen solchen Namen hat.
	 */
	public static AttUsvKommunikationsZustand getZustand(final String value) {
		for (AttUsvKommunikationsZustand e : getZustaende()) {
			if (e.toString().equals(value)) {
				return e;
			}
		}
		return null;
	}
	
	/**
	 * Gibt alle Zustände zurück, die das Attribut besitzen kann.
	 *
	 * @return alle Zustände die das Attribut annehmen kann.
	 */
	public static List<AttUsvKommunikationsZustand> getZustaende() {
		List<AttUsvKommunikationsZustand> list = new ArrayList<AttUsvKommunikationsZustand>();
		list.add(ZUSTAND_1N_NICHT_ERMITTELBAR);
		list.add(ZUSTAND_0_KOMMUNIKATIONSSTOERUNG);
		list.add(ZUSTAND_1_IN_ORDNUNG);
		return list;
	}	
	/**
	 * Erzeugte eine neues Attribut Kommunikationszustand.
	 *
	 * @param value der Wert der Zahl.
	 */
	public AttUsvKommunikationsZustand(final 		Byte
	 value) {
		super(value);
	}
	
	private AttUsvKommunikationsZustand(final String zustand, final 		Byte
	 value) {
		super(zustand, value);
	}
	
}
