/*
 * Java-Modell des Datenkatalogs.
 * Copyright (C) 2016 BitCtrl Systems GmbH 
 * 
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for more
 * details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA.
 *
 * Contact Information:
 * BitCtrl Systems GmbH
 * Weißenfelser Straße 67
 * 04229 Leipzig
 * Phone: +49 341-490670
 * mailto: info@bitctrl.de
 */

package de.bsvrz.sys.funclib.bitctrl.modell.tmverkehrglobal.attribute;

import java.util.*;

import com.bitctrl.beans.*;

import de.bsvrz.dav.daf.main.*;
import de.bsvrz.dav.daf.main.config.*;
import de.bsvrz.sys.funclib.bitctrl.modell.*;
import de.bsvrz.sys.funclib.bitctrl.modell.annotation.*;
import de.bsvrz.sys.funclib.bitctrl.modell.att.*;
import de.bsvrz.sys.funclib.bitctrl.modell.impl.*;

/**
Faktor, mit dem die Werte bei der Berechnung
					berücksichtigt werden sollen. Für die Standardwerte
					+-1.00 sind die Zustände "Zufluss" und "Abfluss"
					vordefiniert.
<p>

</p>
* @author BitCtrl Systems GmbH, M2T
 * @version Gültig seit KB-Version 1
 */
@Wertebereich(
	minimum = -100L,
	maximum = 100L,
	skalierung = 0.01,
	einheit = ""
)
public class AttMessQuerschnittAnteil extends Zahl<		Double
> {
	
	private static final long serialVersionUID = 1L;
	
	/**
	 * Der minimale Wert des Attributs.
	 *
	 * @deprecated neu: {@link WerteBereich#getWerteBereich(Class)} und {@link #getWerteBereich()}
	 */
	@Deprecated
	public static final 		Double
	 MIN_VALUE =
			(		double
			) (		Double
			.valueOf("-100") * 		Double
			.valueOf("0.01"));	
	
	/**
	 * Der maximale Wert des Attributs.
	 *
	 * @deprecated neu: {@link WerteBereich#getWerteBereich(Class)} und {@link #getWerteBereich()}
	 */
	@Deprecated
	public static final 		Double
	 MAX_VALUE =
			(		double
			) (		Double
			.valueOf("100") * 		Double
			.valueOf("0.01"));	
	
	/**
	 * Die Einheit.
	 *
	 * @deprecated neu: {@link WerteBereich#getWerteBereich(Class)} und {@link #getWerteBereich()}
	 */
	@Deprecated
	public static final String EINHEIT = "";
	
	/**
	Werte sind als Abfluss zu werten
								(Subtraktion der Werte).
	<p>
	
	</p>
	*/
	public static final AttMessQuerschnittAnteil ZUSTAND_100N_ABFLUSS = new AttMessQuerschnittAnteil("Abfluss", 		Double
	.valueOf("-100"));

	/**
	Werte sind als Zufluss zu werten (Addition
								der Werte).
	<p>
	
	</p>
	*/
	public static final AttMessQuerschnittAnteil ZUSTAND_100_ZUFLUSS = new AttMessQuerschnittAnteil("Zufluss", 		Double
	.valueOf("100"));

	/**
	 * Gibt den Zustand zu einer Zahl zurück oder <code>null</code>, wenn die
	 * Zahl keinen Zustand repräsentiert.
	 *
	 * @param value ein Zahlenwert
	 * @return der Zustand zu dem Zahlenwert oder <code>null</code>, wenn die
	 * Zahl keine Entsprechnung als Zustand besitzt.
	 */
	public static AttMessQuerschnittAnteil getZustand(final 		Double
	 value) {
		for (AttMessQuerschnittAnteil e : getZustaende()) {
			if (e.getValue().equals(value)) {
				return e;
			}
		}
		return null;
	}
	
	/**
	 * Gibt den Zustand zu einem Zustandsnamen zurück oder <code>null</code>,
	 * wenn kein Zustand einen solchen Namen hat.
	 * 
	 * @param value
	 *            der Zustandsname
	 * @return der Zustand zu dem Zustandsnamen oder <code>null</code>, wenn
	 *         kein Zustand einen solchen Namen hat.
	 */
	public static AttMessQuerschnittAnteil getZustand(final String value) {
		for (AttMessQuerschnittAnteil e : getZustaende()) {
			if (e.toString().equals(value)) {
				return e;
			}
		}
		return null;
	}
	
	/**
	 * Gibt alle Zustände zurück, die das Attribut besitzen kann.
	 *
	 * @return alle Zustände die das Attribut annehmen kann.
	 */
	public static List<AttMessQuerschnittAnteil> getZustaende() {
		List<AttMessQuerschnittAnteil> list = new ArrayList<AttMessQuerschnittAnteil>();
		list.add(ZUSTAND_100N_ABFLUSS);
		list.add(ZUSTAND_100_ZUFLUSS);
		return list;
	}	
	/**
	 * Erzeugte eine neues Attribut MessQuerschnittAnteil.
	 *
	 * @param value der Wert der Zahl.
	 */
	public AttMessQuerschnittAnteil(final 		Double
	 value) {
		super(value);
	}
	
	private AttMessQuerschnittAnteil(final String zustand, final 		Double
	 value) {
		super(zustand, value);
	}
	
}
