/*
 * Java-Modell des Datenkatalogs.
 * Copyright (C) 2016 BitCtrl Systems GmbH 
 * 
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for more
 * details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA.
 *
 * Contact Information:
 * BitCtrl Systems GmbH
 * Weißenfelser Straße 67
 * 04229 Leipzig
 * Phone: +49 341-490670
 * mailto: info@bitctrl.de
 */

package de.bsvrz.sys.funclib.bitctrl.modell.tmverkehrglobal.attribute;

import java.util.*;

import com.bitctrl.beans.*;

import de.bsvrz.dav.daf.main.*;
import de.bsvrz.dav.daf.main.config.*;
import de.bsvrz.sys.funclib.bitctrl.modell.*;
import de.bsvrz.sys.funclib.bitctrl.modell.annotation.*;
import de.bsvrz.sys.funclib.bitctrl.modell.att.*;
import de.bsvrz.sys.funclib.bitctrl.modell.impl.*;

/**
Lage des virtuellen Messquerschnitts.
<p>

</p>
* @author BitCtrl Systems GmbH, M2T
 * @version Gültig seit KB-Version 1
 */
public class AttMessQuerschnittVirtuellLage extends Zahl<		Byte
> {
	
	private static final long serialVersionUID = 1L;
	
	
	/**
	Messquerschnitt VOR der Anschlussstelle.
	<p>
	
	</p>
	*/
	public static final AttMessQuerschnittVirtuellLage ZUSTAND_0_VOR = new AttMessQuerschnittVirtuellLage("Vor", 		Byte
	.valueOf("0"));

	/**
	Messquerschnitt MITTE der Anschlussstelle.
	<p>
	
	</p>
	*/
	public static final AttMessQuerschnittVirtuellLage ZUSTAND_1_MITTE = new AttMessQuerschnittVirtuellLage("Mitte", 		Byte
	.valueOf("1"));

	/**
	Messquerschnitt NACH der Anschlussstelle.
	<p>
	
	</p>
	*/
	public static final AttMessQuerschnittVirtuellLage ZUSTAND_2_NACH = new AttMessQuerschnittVirtuellLage("Nach", 		Byte
	.valueOf("2"));

	/**
	Messquerschnitt AUSFAHRT der
								Anschlussstelle.
	<p>
	
	</p>
	*/
	public static final AttMessQuerschnittVirtuellLage ZUSTAND_3_AUSFAHRT = new AttMessQuerschnittVirtuellLage("Ausfahrt", 		Byte
	.valueOf("3"));

	/**
	Messquerschnitt EINFAHRT der
								Anschlussstelle.
	<p>
	
	</p>
	*/
	public static final AttMessQuerschnittVirtuellLage ZUSTAND_4_EINFAHRT = new AttMessQuerschnittVirtuellLage("Einfahrt", 		Byte
	.valueOf("4"));

	/**
	 * Gibt den Zustand zu einer Zahl zurück oder <code>null</code>, wenn die
	 * Zahl keinen Zustand repräsentiert.
	 *
	 * @param value ein Zahlenwert
	 * @return der Zustand zu dem Zahlenwert oder <code>null</code>, wenn die
	 * Zahl keine Entsprechnung als Zustand besitzt.
	 */
	public static AttMessQuerschnittVirtuellLage getZustand(final 		Byte
	 value) {
		for (AttMessQuerschnittVirtuellLage e : getZustaende()) {
			if (e.getValue().equals(value)) {
				return e;
			}
		}
		return null;
	}
	
	/**
	 * Gibt den Zustand zu einem Zustandsnamen zurück oder <code>null</code>,
	 * wenn kein Zustand einen solchen Namen hat.
	 * 
	 * @param value
	 *            der Zustandsname
	 * @return der Zustand zu dem Zustandsnamen oder <code>null</code>, wenn
	 *         kein Zustand einen solchen Namen hat.
	 */
	public static AttMessQuerschnittVirtuellLage getZustand(final String value) {
		for (AttMessQuerschnittVirtuellLage e : getZustaende()) {
			if (e.toString().equals(value)) {
				return e;
			}
		}
		return null;
	}
	
	/**
	 * Gibt alle Zustände zurück, die das Attribut besitzen kann.
	 *
	 * @return alle Zustände die das Attribut annehmen kann.
	 */
	public static List<AttMessQuerschnittVirtuellLage> getZustaende() {
		List<AttMessQuerschnittVirtuellLage> list = new ArrayList<AttMessQuerschnittVirtuellLage>();
		list.add(ZUSTAND_0_VOR);
		list.add(ZUSTAND_1_MITTE);
		list.add(ZUSTAND_2_NACH);
		list.add(ZUSTAND_3_AUSFAHRT);
		list.add(ZUSTAND_4_EINFAHRT);
		return list;
	}	
	/**
	 * Erzeugte eine neues Attribut MessQuerschnittVirtuellLage.
	 *
	 * @param value der Wert der Zahl.
	 */
	public AttMessQuerschnittVirtuellLage(final 		Byte
	 value) {
		super(value);
	}
	
	private AttMessQuerschnittVirtuellLage(final String zustand, final 		Byte
	 value) {
		super(zustand, value);
	}
	
}
