/*
 * Java-Modell des Datenkatalogs.
 * Copyright (C) 2016 BitCtrl Systems GmbH 
 * 
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for more
 * details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA.
 *
 * Contact Information:
 * BitCtrl Systems GmbH
 * Weißenfelser Straße 67
 * 04229 Leipzig
 * Phone: +49 341-490670
 * mailto: info@bitctrl.de
 */

package de.bsvrz.sys.funclib.bitctrl.modell.tmverkehrglobal.attribute;

import java.util.*;

import com.bitctrl.beans.*;

import de.bsvrz.dav.daf.main.*;
import de.bsvrz.dav.daf.main.config.*;
import de.bsvrz.sys.funclib.bitctrl.modell.*;
import de.bsvrz.sys.funclib.bitctrl.modell.annotation.*;
import de.bsvrz.sys.funclib.bitctrl.modell.att.*;
import de.bsvrz.sys.funclib.bitctrl.modell.impl.*;

/**
Definition eines Ganglinienwertes.
<p>
&lt;absatz&gt;
						Es wird festgelegt, welcher Wertebereich bzw.
						Zustände ein Ganglinienwert annehmen kann.
					&lt;&#47;absatz&gt;
</p>
* @author BitCtrl Systems GmbH, M2T
 * @version Gültig seit KB-Version 19
 */
@Wertebereich(
	minimum = -100000L,
	maximum = 100000L,
	einheit = ""
)
public class AttNbaGanglinienWert extends Zahl<		Long
> {
	
	private static final long serialVersionUID = 1L;
	
	/**
	 * Der minimale Wert des Attributs.
	 *
	 * @deprecated neu: {@link WerteBereich#getWerteBereich(Class)} und {@link #getWerteBereich()}
	 */
	@Deprecated
	public static final 		Long
	 MIN_VALUE =
				Long
		.valueOf("-100000");
	
	/**
	 * Der maximale Wert des Attributs.
	 *
	 * @deprecated neu: {@link WerteBereich#getWerteBereich(Class)} und {@link #getWerteBereich()}
	 */
	@Deprecated
	public static final 		Long
	 MAX_VALUE =
				Long
		.valueOf("100000");
	
	/**
	 * Die Einheit.
	 *
	 * @deprecated neu: {@link WerteBereich#getWerteBereich(Class)} und {@link #getWerteBereich()}
	 */
	@Deprecated
	public static final String EINHEIT = "";
	
	/**
	
	<p>
	
	</p>
	*/
	public static final AttNbaGanglinienWert ZUSTAND_100001N_NICHT_ERMITTELBAR = new AttNbaGanglinienWert("nicht ermittelbar", 		Long
	.valueOf("-100001"));

	/**
	
	<p>
	
	</p>
	*/
	public static final AttNbaGanglinienWert ZUSTAND_100002N_FEHLERHAFT = new AttNbaGanglinienWert("fehlerhaft", 		Long
	.valueOf("-100002"));

	/**
	
	<p>
	
	</p>
	*/
	public static final AttNbaGanglinienWert ZUSTAND_100003N_NICHT_ERMITTELBAR_FEHLERHAFT = new AttNbaGanglinienWert("nicht ermittelbar/fehlerhaft", 		Long
	.valueOf("-100003"));

	/**
	 * Gibt den Zustand zu einer Zahl zurück oder <code>null</code>, wenn die
	 * Zahl keinen Zustand repräsentiert.
	 *
	 * @param value ein Zahlenwert
	 * @return der Zustand zu dem Zahlenwert oder <code>null</code>, wenn die
	 * Zahl keine Entsprechnung als Zustand besitzt.
	 */
	public static AttNbaGanglinienWert getZustand(final 		Long
	 value) {
		for (AttNbaGanglinienWert e : getZustaende()) {
			if (e.getValue().equals(value)) {
				return e;
			}
		}
		return null;
	}
	
	/**
	 * Gibt den Zustand zu einem Zustandsnamen zurück oder <code>null</code>,
	 * wenn kein Zustand einen solchen Namen hat.
	 * 
	 * @param value
	 *            der Zustandsname
	 * @return der Zustand zu dem Zustandsnamen oder <code>null</code>, wenn
	 *         kein Zustand einen solchen Namen hat.
	 */
	public static AttNbaGanglinienWert getZustand(final String value) {
		for (AttNbaGanglinienWert e : getZustaende()) {
			if (e.toString().equals(value)) {
				return e;
			}
		}
		return null;
	}
	
	/**
	 * Gibt alle Zustände zurück, die das Attribut besitzen kann.
	 *
	 * @return alle Zustände die das Attribut annehmen kann.
	 */
	public static List<AttNbaGanglinienWert> getZustaende() {
		List<AttNbaGanglinienWert> list = new ArrayList<AttNbaGanglinienWert>();
		list.add(ZUSTAND_100001N_NICHT_ERMITTELBAR);
		list.add(ZUSTAND_100002N_FEHLERHAFT);
		list.add(ZUSTAND_100003N_NICHT_ERMITTELBAR_FEHLERHAFT);
		return list;
	}	
	/**
	 * Erzeugte eine neues Attribut nbaGanglinienWert.
	 *
	 * @param value der Wert der Zahl.
	 */
	public AttNbaGanglinienWert(final 		Long
	 value) {
		super(value);
	}
	
	private AttNbaGanglinienWert(final String zustand, final 		Long
	 value) {
		super(zustand, value);
	}
	
}
