/*
 * Java-Modell des Datenkatalogs.
 * Copyright (C) 2016 BitCtrl Systems GmbH 
 * 
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for more
 * details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA.
 *
 * Contact Information:
 * BitCtrl Systems GmbH
 * Weißenfelser Straße 67
 * 04229 Leipzig
 * Phone: +49 341-490670
 * mailto: info@bitctrl.de
 */

package de.bsvrz.sys.funclib.bitctrl.modell.modellkextlslkwparken.attribute;

import java.util.*;

import com.bitctrl.beans.*;

import de.bsvrz.dav.daf.main.*;
import de.bsvrz.dav.daf.main.config.*;
import de.bsvrz.sys.funclib.bitctrl.modell.*;
import de.bsvrz.sys.funclib.bitctrl.modell.annotation.*;
import de.bsvrz.sys.funclib.bitctrl.modell.att.*;
import de.bsvrz.sys.funclib.bitctrl.modell.impl.*;

/**
Die ID-Nummer ist eine laufende Nummer im Bereich von 0 bis 65535 (2 Byte).
                    Nach Erreichen des Wertes 65535 wird einem neu identifizierten Fahrzeug die nächste
                    freie ID-Nummer größer 0 zugeordnet.
                    Fahrzeuge, die nicht eindeutig identifiziert werden konnten, erhalten die spezielle ID-Nummer 0.
<p>

</p>
* @author BitCtrl Systems GmbH, M2T
 * @version Gültig seit KB-Version 4
 */
@Wertebereich(
	minimum = 1L,
	maximum = 65535L,
	einheit = ""
)
public class AttTlsPpueFahrzeugId extends Zahl<		Integer
> {
	
	private static final long serialVersionUID = 1L;
	
	/**
	 * Der minimale Wert des Attributs.
	 *
	 * @deprecated neu: {@link WerteBereich#getWerteBereich(Class)} und {@link #getWerteBereich()}
	 */
	@Deprecated
	public static final 		Integer
	 MIN_VALUE =
				Integer
		.valueOf("1");
	
	/**
	 * Der maximale Wert des Attributs.
	 *
	 * @deprecated neu: {@link WerteBereich#getWerteBereich(Class)} und {@link #getWerteBereich()}
	 */
	@Deprecated
	public static final 		Integer
	 MAX_VALUE =
				Integer
		.valueOf("65535");
	
	/**
	 * Die Einheit.
	 *
	 * @deprecated neu: {@link WerteBereich#getWerteBereich(Class)} und {@link #getWerteBereich()}
	 */
	@Deprecated
	public static final String EINHEIT = "";
	
	/**
	Fahrzeug-ID ist nicht ermittelbar (Kein Fehler, z.B. keine Identifizierung möglich, da der Wert nicht erfasst wird).
	<p>
	
	</p>
	*/
	public static final AttTlsPpueFahrzeugId ZUSTAND_1N_NICHT_ERMITTELBAR = new AttTlsPpueFahrzeugId("nicht ermittelbar", 		Integer
	.valueOf("-1"));

	/**
	Fahrzeug konnte nicht identifiziert werden.
	<p>
	
	</p>
	*/
	public static final AttTlsPpueFahrzeugId ZUSTAND_0_NICHT_IDENTIFIZIERBAR = new AttTlsPpueFahrzeugId("nicht identifizierbar", 		Integer
	.valueOf("0"));

	/**
	 * Gibt den Zustand zu einer Zahl zurück oder <code>null</code>, wenn die
	 * Zahl keinen Zustand repräsentiert.
	 *
	 * @param value ein Zahlenwert
	 * @return der Zustand zu dem Zahlenwert oder <code>null</code>, wenn die
	 * Zahl keine Entsprechnung als Zustand besitzt.
	 */
	public static AttTlsPpueFahrzeugId getZustand(final 		Integer
	 value) {
		for (AttTlsPpueFahrzeugId e : getZustaende()) {
			if (e.getValue().equals(value)) {
				return e;
			}
		}
		return null;
	}
	
	/**
	 * Gibt den Zustand zu einem Zustandsnamen zurück oder <code>null</code>,
	 * wenn kein Zustand einen solchen Namen hat.
	 * 
	 * @param value
	 *            der Zustandsname
	 * @return der Zustand zu dem Zustandsnamen oder <code>null</code>, wenn
	 *         kein Zustand einen solchen Namen hat.
	 */
	public static AttTlsPpueFahrzeugId getZustand(final String value) {
		for (AttTlsPpueFahrzeugId e : getZustaende()) {
			if (e.toString().equals(value)) {
				return e;
			}
		}
		return null;
	}
	
	/**
	 * Gibt alle Zustände zurück, die das Attribut besitzen kann.
	 *
	 * @return alle Zustände die das Attribut annehmen kann.
	 */
	public static List<AttTlsPpueFahrzeugId> getZustaende() {
		List<AttTlsPpueFahrzeugId> list = new ArrayList<AttTlsPpueFahrzeugId>();
		list.add(ZUSTAND_1N_NICHT_ERMITTELBAR);
		list.add(ZUSTAND_0_NICHT_IDENTIFIZIERBAR);
		return list;
	}	
	/**
	 * Erzeugte eine neues Attribut Fahrzeug ID.
	 *
	 * @param value der Wert der Zahl.
	 */
	public AttTlsPpueFahrzeugId(final 		Integer
	 value) {
		super(value);
	}
	
	private AttTlsPpueFahrzeugId(final String zustand, final 		Integer
	 value) {
		super(zustand, value);
	}
	
}
