/*
 * Java-Modell des Datenkatalogs.
 * Copyright (C) 2016 BitCtrl Systems GmbH 
 * 
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for more
 * details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA.
 *
 * Contact Information:
 * BitCtrl Systems GmbH
 * Weißenfelser Straße 67
 * 04229 Leipzig
 * Phone: +49 341-490670
 * mailto: info@bitctrl.de
 */

package de.bsvrz.sys.funclib.bitctrl.modell.tmbitctrlswis.parameter;

import java.util.*;

import com.bitctrl.beans.*;

import de.bsvrz.dav.daf.main.*;
import de.bsvrz.dav.daf.main.config.*;
import de.bsvrz.sys.funclib.bitctrl.modell.*;
import de.bsvrz.sys.funclib.bitctrl.modell.annotation.*;
import de.bsvrz.sys.funclib.bitctrl.modell.att.*;
import de.bsvrz.sys.funclib.bitctrl.modell.impl.*;

/**
Parameter, der die letzte versandte Benachrichtigung
					enthält.
<p>

</p>
* @author BitCtrl Systems GmbH, M2T
 * @version Gültig seit KB-Version 16
 */
public class PdParameterLetzteBenachrichtigung extends AbstractParameterDatensatz<PdParameterLetzteBenachrichtigung.Daten> {

		/**
		 * Die vorhandenen Aspekte des Datensatzes.
		 */
		public static class Aspekte extends de.bsvrz.sys.funclib.bitctrl.modell.metamodellglobal.objekte.impl.AspektImpl implements Aspekt {
	
			public static Aspekt[] values() {
				return new Aspekt[] {
					Aspekte.ParameterDefault,
					Aspekte.ParameterSoll,
					Aspekte.ParameterVorgabe,
					Aspekte.ParameterIst,
				};
			}
	
			/**
			 * Aspekt der zur Versorgung von Defaultwerten für Parameter verwendet werden kann.	 
			 *
			 * <p>
			 * 
	         * </p>
			 */
			public static final Aspekt ParameterDefault = new Aspekte("Default-Parameter-Aspekt", "asp.parameterDefault");
			
			/**
			 * Wird für Parametersätze als Platzhalter verwendet und später durch die Konfiguration automatisch durch die zugesicherten Aspekte von Parametern ersetzt.	 
			 *
			 * <p>
			 * 
	         * </p>
			 */
			public static final Aspekt ParameterSoll = new Aspekte("Soll-Parameter-Aspekt", "asp.parameterSoll");
			
			/**
			 * Wird für Parametersätze als Platzhalter verwendet und später durch die Konfiguration automatisch durch die zugesicherten Aspekte von Parametern ersetzt.	 
			 *
			 * <p>
			 * 
	         * </p>
			 */
			public static final Aspekt ParameterVorgabe = new Aspekte("Vorgabe-Parameter-Aspekt", "asp.parameterVorgabe");
			
			/**
			 * Wird für Parametersätze als Platzhalter verwendet und später durch die Konfiguration automatisch durch die zugesicherten Aspekte von Parametern ersetzt.	 
			 *
			 * <p>
			 * 
	         * </p>
			 */
			public static final Aspekt ParameterIst = new Aspekte("Ist-Parameter-Aspekt", "asp.parameterIst");
			
			;
			
			private final String name;
			private final String pid;
	
			private Aspekte(final String name, final String pid) {
				this.name = name;
				this.pid = pid;
			}
	
			@Override
			public String getName() {
				if (getSystemObject() == null) {
					return name;
				}
				return super.getName();
			}
	
			@Override
			public String getPid() {
				if (getSystemObject() == null) {
					return pid;
				}
				return super.getPid();
			}
			
			@Override
			public Aspect getSystemObject() {
				return (Aspect) super.getSystemObject();
			}
	
			@Override
			public String toString() {
				if (getSystemObject() == null) {
					return name + " (" + pid + ")";
				}
				return super.toString();
			}
	
		}
	
	/**
	 * Kapselt die Daten des Datensatzes.
	 */
	public static class Daten extends AbstractOnlineDatum {
		
		/**
		 * Initialisiert das Onlinedatum.
		 * 
		 * @param datensatz
		 *            der Datensatz zu dem das Datum gehört.
		 * @param aspekt
		 *            der Aspekt für das Datum.
		 */
		public Daten(final Datensatz datensatz, final Aspekt aspekt) {
			super(datensatz, aspekt);
		}
		
		
			/*
			 * Beginn Propertiesabschnitt
			 */
		
				private de.bsvrz.sys.funclib.bitctrl.modell.tmvewbetriebglobal.attribute.AtlUrlasser
				 _urlasser
				= new de.bsvrz.sys.funclib.bitctrl.modell.tmvewbetriebglobal.attribute.AtlUrlasser
				()
				;
				private de.bsvrz.sys.funclib.bitctrl.modell.tmbitctrlswis.attribute.AttArtBenachrichtigung
				 _art
				;
				private de.bsvrz.sys.funclib.bitctrl.modell.tmbitctrlswis.attribute.AttZustandBenachrichtigung
				 _zustand
				;
				private String
				 _text
				= new String
				()
				;
				private de.bsvrz.sys.funclib.bitctrl.modell.tmbitctrlswis.attribute.AttStandardAktionen
				 _aktion
				;
				private String
				 _empfaenger
				= new String
				()
				;
		
			/**
			Urlasserinformationen.
			<p>
			Urlasserinformationen bestehen aus einer Referenz auf den Benutzer, der die Meldung erzeugt hat, einer Angabe der Ursache für die Meldung und einem Veranlasser für die Meldung.
			</p>
			
			@return der Wert von Urlasser.
			*/
				public de.bsvrz.sys.funclib.bitctrl.modell.tmvewbetriebglobal.attribute.AtlUrlasser
				 getUrlasser() {
				return _urlasser;
			}
		
			/**
			Urlasserinformationen.
			<p>
			Urlasserinformationen bestehen aus einer Referenz auf den Benutzer, der die Meldung erzeugt hat, einer Angabe der Ursache für die Meldung und einem Veranlasser für die Meldung.
			</p>
			
			@param _urlasser der neue Wert von Urlasser.
			*/
			public void setUrlasser(de.bsvrz.sys.funclib.bitctrl.modell.tmvewbetriebglobal.attribute.AtlUrlasser
			 _urlasser) {
				this._urlasser = _urlasser;
			}
		
			/**
			Arten der Benachrichtigung für SWIS Meldungen.
			<p>
			
			</p>
			
			@return der Wert von Art.
			*/
				public de.bsvrz.sys.funclib.bitctrl.modell.tmbitctrlswis.attribute.AttArtBenachrichtigung
				 getArt() {
				return _art;
			}
		
			/**
			Arten der Benachrichtigung für SWIS Meldungen.
			<p>
			
			</p>
			
			@param _art der neue Wert von Art.
			*/
			public void setArt(de.bsvrz.sys.funclib.bitctrl.modell.tmbitctrlswis.attribute.AttArtBenachrichtigung
			 _art) {
				this._art = _art;
			}
		
			/**
			Der Zustand einer Benachrichtigung für SWIS Meldungen.
			<p>
			
			</p>
			
			@return der Wert von Zustand.
			*/
				public de.bsvrz.sys.funclib.bitctrl.modell.tmbitctrlswis.attribute.AttZustandBenachrichtigung
				 getZustand() {
				return _zustand;
			}
		
			/**
			Der Zustand einer Benachrichtigung für SWIS Meldungen.
			<p>
			
			</p>
			
			@param _zustand der neue Wert von Zustand.
			*/
			public void setZustand(de.bsvrz.sys.funclib.bitctrl.modell.tmbitctrlswis.attribute.AttZustandBenachrichtigung
			 _zustand) {
				this._zustand = _zustand;
			}
		
			/**
			Attribut zur Speicherung eines Textes.
			<p>
			
			</p>
			
			@return der Wert von Text.
			*/
				public String
				 getText() {
				return _text;
			}
		
			/**
			Attribut zur Speicherung eines Textes.
			<p>
			
			</p>
			
			@param _text der neue Wert von Text.
			*/
			public void setText(String
			 _text) {
				if (_text.length() > 32767) {
					throw new IllegalArgumentException("Der Text darf nicht länger als " + 32767 + " Zeichen sein.");
				}
				this._text = _text;
			}
		
			/**
			Menge der Standardaktionen, die Aufgrund einer SWIS
								Benachrichtigung ausgeführt werden
								sollen.
			<p>
			
			</p>
			
			@return der Wert von Aktion.
			*/
				public de.bsvrz.sys.funclib.bitctrl.modell.tmbitctrlswis.attribute.AttStandardAktionen
				 getAktion() {
				return _aktion;
			}
		
			/**
			Menge der Standardaktionen, die Aufgrund einer SWIS
								Benachrichtigung ausgeführt werden
								sollen.
			<p>
			
			</p>
			
			@param _aktion der neue Wert von Aktion.
			*/
			public void setAktion(de.bsvrz.sys.funclib.bitctrl.modell.tmbitctrlswis.attribute.AttStandardAktionen
			 _aktion) {
				this._aktion = _aktion;
			}
		
			/**
			Attribut zur Speicherung eines Textes.
			<p>
			
			</p>
			
			@return der Wert von Empfaenger.
			*/
				public String
				 getEmpfaenger() {
				return _empfaenger;
			}
		
			/**
			Attribut zur Speicherung eines Textes.
			<p>
			
			</p>
			
			@param _empfaenger der neue Wert von Empfaenger.
			*/
			public void setEmpfaenger(String
			 _empfaenger) {
				if (_empfaenger.length() > 32767) {
					throw new IllegalArgumentException("Der Text darf nicht länger als " + 32767 + " Zeichen sein.");
				}
				this._empfaenger = _empfaenger;
			}
		
		
			/*
			 * Ende Propertiesabschnitt
			 */
		
			/*
			 * Beginn Abschnitt Konvertierung Datenverteiler <-> Modell
			 */
		
			public void bean2Atl(final Data datum, final ObjektFactory factory) {
					// AttributListenDefinition
						getUrlasser().bean2Atl(datum.getItem("Urlasser"), factory);
					// GanzzahlAttributTyp
					if (getArt() != null) {
		                if (getArt().isZustand()) {
		                    datum.getUnscaledValue("art").setText(getArt().toString());
		                } else {
							datum.
							getUnscaledValue
		                	("art").set(getArt().getValue());
		                }
					}
					// GanzzahlAttributTyp
					if (getZustand() != null) {
		                if (getZustand().isZustand()) {
		                    datum.getUnscaledValue("zustand").setText(getZustand().toString());
		                } else {
							datum.
							getUnscaledValue
		                	("zustand").set(getZustand().getValue());
		                }
					}
					// ZeichenkettenAttributTyp
					if (getText() != null) {
						datum.getTextValue("text").setText(getText());
					}
					// GanzzahlAttributTyp
					if (getAktion() != null) {
		                if (getAktion().isZustand()) {
		                    datum.getUnscaledValue("aktion").setText(getAktion().toString());
		                } else {
							datum.
							getUnscaledValue
		                	("aktion").set(getAktion().getValue());
		                }
					}
					// ZeichenkettenAttributTyp
					if (getEmpfaenger() != null) {
						datum.getTextValue("empfaenger").setText(getEmpfaenger());
					}
			}
		
			public void atl2Bean(final Data daten, final ObjektFactory factory) {
					// AttributListenDefinition
						getUrlasser().atl2Bean(daten.getItem("Urlasser"), factory);
					// GanzzahlAttributTyp
							if (daten.getUnscaledValue("art").isState()) {
								setArt(de.bsvrz.sys.funclib.bitctrl.modell.tmbitctrlswis.attribute.AttArtBenachrichtigung
								.getZustand(daten.getScaledValue("art").getText()));
							} else {
							setArt(new de.bsvrz.sys.funclib.bitctrl.modell.tmbitctrlswis.attribute.AttArtBenachrichtigung
							(daten.
								getUnscaledValue
							("art").
									byteValue
							()));
							}
					// GanzzahlAttributTyp
							if (daten.getUnscaledValue("zustand").isState()) {
								setZustand(de.bsvrz.sys.funclib.bitctrl.modell.tmbitctrlswis.attribute.AttZustandBenachrichtigung
								.getZustand(daten.getScaledValue("zustand").getText()));
							} else {
							setZustand(new de.bsvrz.sys.funclib.bitctrl.modell.tmbitctrlswis.attribute.AttZustandBenachrichtigung
							(daten.
								getUnscaledValue
							("zustand").
									byteValue
							()));
							}
					// ZeichenkettenAttributTyp
						setText(daten.getTextValue("text").getText());
					// GanzzahlAttributTyp
							if (daten.getUnscaledValue("aktion").isState()) {
								setAktion(de.bsvrz.sys.funclib.bitctrl.modell.tmbitctrlswis.attribute.AttStandardAktionen
								.getZustand(daten.getScaledValue("aktion").getText()));
							} else {
							setAktion(new de.bsvrz.sys.funclib.bitctrl.modell.tmbitctrlswis.attribute.AttStandardAktionen
							(daten.
								getUnscaledValue
							("aktion").
									byteValue
							()));
							}
					// ZeichenkettenAttributTyp
						setEmpfaenger(daten.getTextValue("empfaenger").getText());
			}
		
			/*
			 * Ende Abschnitt Konvertierung Datenverteiler <-> Modell
			 */
		
			
		@Override
		public Daten clone() {
			final Daten klon = new Daten(dGetDatensatz(), dGetAspekt());
	
							klon._urlasser = getUrlasser().clone();
							klon.setArt(getArt());
							klon.setZustand(getZustand());
							klon.setText(getText());
							klon.setAktion(getAktion());
							klon.setEmpfaenger(getEmpfaenger());
			
			
			klon.dSetZeitstempel(dGetZeitstempel());
			klon.dSetDatenStatus(dGetDatenStatus());
	
			return klon;
		}

		@Override
		public String toString() {
			return BeanUtils.toString(this);
		}
	
	}

		/** Die PID der Attributgruppe im Datenverteiler. */
		public static final String PID = "atg.parameterLetzteBenachrichtigung";

	/**
	 * Initialisiert den Parameterdatensatz.
	 * 
	 * @param systemObjekt
	 *            das Systemobjekt zu dem der Datensatz gehört.
	 * @param objektFactory
	 *            die ObjektFabrik, die der Datensatz verwenden soll.
	 */
	public PdParameterLetzteBenachrichtigung(final SystemObjekt systemObjekt,
			final ObjektFactory objektFactory) {
		super(systemObjekt, objektFactory);
	}

	
		@Override
		public void init(final SystemObject systemObject,
				final ObjektFactory objektFactory) {
			super.init(systemObject, objektFactory);
			for (final Aspekt asp : Aspekte.values()) {
				((AbstractSystemObjekt) asp).init(objektFactory.getModellobjekt(asp.getPid()).getSystemObject(), objektFactory);
			}
		}
		
		@Override
		protected String doGetPid() {
			return PID;
		}
	
		public Collection<? extends Aspekt> getAspekte() {
			return Arrays.asList(Aspekte.values());
		}
	
		public Daten createDatum() {
			Daten datum = new Daten(this, null);
			// TODO Auslesen der Defaultwerte geht nicht,
			// weil der Datenverteiler für Attribute ohne Defaultwert initial ungültige Werte setzt!!
			// datum.atl2Bean(createSendeCache(), getObjektFactory());
			return datum;
		}
		 

}
