/*
 * Java-Modell des Datenkatalogs.
 * Copyright (C) 2016 BitCtrl Systems GmbH 
 * 
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for more
 * details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA.
 *
 * Contact Information:
 * BitCtrl Systems GmbH
 * Weißenfelser Straße 67
 * 04229 Leipzig
 * Phone: +49 341-490670
 * mailto: info@bitctrl.de
 */

package de.bsvrz.sys.funclib.bitctrl.modell.tmkextlsglobal.attribute;

import java.util.*;

import com.bitctrl.beans.*;

import de.bsvrz.dav.daf.main.*;
import de.bsvrz.dav.daf.main.config.*;
import de.bsvrz.sys.funclib.bitctrl.modell.*;
import de.bsvrz.sys.funclib.bitctrl.modell.annotation.*;
import de.bsvrz.sys.funclib.bitctrl.modell.att.*;
import de.bsvrz.sys.funclib.bitctrl.modell.impl.*;

/**
Wasserfilmdicke.
<p>
Bei WFD oberhalb 0,1 mm wird nur eine
					Messgenauigkeit im 1&#47;10 mm Bereich erreicht. Bei WFD
					oberhalb 2 mm liegt die Messgenauigkeit in der Regel
					im mm Bereich. Die rechnerische Wasserfilmdicke gibt
					die Fahrbahnbenetzung in mm (= Liter&#47;m2 ) mit Wasser
					oder wässriger Lösung (Salzgemisch) an, welche sich
					am Messort bzw. auf der in der Fahrbahn
					eingelassenen Sonde befindet. Die Wasserfilmdicke
					ist immer bezogen auf eine glatte ebene Fläche.
</p>
* @author BitCtrl Systems GmbH, M2T
 * @version Gültig seit KB-Version 1
 */
@Wertebereich(
	minimum = 0L,
	maximum = 65534L,
	skalierung = 0.01,
	einheit = "mm"
)
public class AttTlsUfdWasserfilmdicke extends Zahl<		Double
> {
	
	private static final long serialVersionUID = 1L;
	
	/**
	 * Der minimale Wert des Attributs.
	 *
	 * @deprecated neu: {@link WerteBereich#getWerteBereich(Class)} und {@link #getWerteBereich()}
	 */
	@Deprecated
	public static final 		Double
	 MIN_VALUE =
					Double
			.valueOf("0") * 		Double
			.valueOf("0.01");
	
	/**
	 * Der maximale Wert des Attributs.
	 *
	 * @deprecated neu: {@link WerteBereich#getWerteBereich(Class)} und {@link #getWerteBereich()}
	 */
	@Deprecated
	public static final 		Double
	 MAX_VALUE =
					Double
			.valueOf("65534") * 		Double
			.valueOf("0.01");
	
	/**
	 * Die Einheit.
	 *
	 * @deprecated neu: {@link WerteBereich#getWerteBereich(Class)} und {@link #getWerteBereich()}
	 */
	@Deprecated
	public static final String EINHEIT = "mm";
	
	/**
	Sensorik kann auf Grund der herrschenden
								Bedingungen Zustand nicht bestimmen.
	<p>
	
	</p>
	*/
	public static final AttTlsUfdWasserfilmdicke ZUSTAND_65535_ZUSTAND_NICHT_ERMITTELBAR = new AttTlsUfdWasserfilmdicke("Zustand nicht ermittelbar", 		Double
	.valueOf("65535"));

	/**
	 * Gibt den Zustand zu einer Zahl zurück oder <code>null</code>, wenn die
	 * Zahl keinen Zustand repräsentiert.
	 *
	 * @param value ein Zahlenwert
	 * @return der Zustand zu dem Zahlenwert oder <code>null</code>, wenn die
	 * Zahl keine Entsprechnung als Zustand besitzt.
	 */
	public static AttTlsUfdWasserfilmdicke getZustand(final 		Double
	 value) {
		for (AttTlsUfdWasserfilmdicke e : getZustaende()) {
			if (e.getValue().equals(value)) {
				return e;
			}
		}
		return null;
	}
	
	/**
	 * Gibt den Zustand zu einem Zustandsnamen zurück oder <code>null</code>,
	 * wenn kein Zustand einen solchen Namen hat.
	 * 
	 * @param value
	 *            der Zustandsname
	 * @return der Zustand zu dem Zustandsnamen oder <code>null</code>, wenn
	 *         kein Zustand einen solchen Namen hat.
	 */
	public static AttTlsUfdWasserfilmdicke getZustand(final String value) {
		for (AttTlsUfdWasserfilmdicke e : getZustaende()) {
			if (e.toString().equals(value)) {
				return e;
			}
		}
		return null;
	}
	
	/**
	 * Gibt alle Zustände zurück, die das Attribut besitzen kann.
	 *
	 * @return alle Zustände die das Attribut annehmen kann.
	 */
	public static List<AttTlsUfdWasserfilmdicke> getZustaende() {
		List<AttTlsUfdWasserfilmdicke> list = new ArrayList<AttTlsUfdWasserfilmdicke>();
		list.add(ZUSTAND_65535_ZUSTAND_NICHT_ERMITTELBAR);
		return list;
	}	
	/**
	 * Erzeugte eine neues Attribut TLSUfdWasserfilmdicke.
	 *
	 * @param value der Wert der Zahl.
	 */
	public AttTlsUfdWasserfilmdicke(final 		Double
	 value) {
		super(value);
	}
	
	private AttTlsUfdWasserfilmdicke(final String zustand, final 		Double
	 value) {
		super(zustand, value);
	}
	
}
