/*
 * Java-Modell des Datenkatalogs.
 * Copyright (C) 2016 BitCtrl Systems GmbH 
 * 
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for more
 * details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA.
 *
 * Contact Information:
 * BitCtrl Systems GmbH
 * Weißenfelser Straße 67
 * 04229 Leipzig
 * Phone: +49 341-490670
 * mailto: info@bitctrl.de
 */

package de.bsvrz.sys.funclib.bitctrl.modell.tmnbaglobal.attribute;

import java.util.*;

import com.bitctrl.beans.*;

import de.bsvrz.dav.daf.main.*;
import de.bsvrz.dav.daf.main.config.*;
import de.bsvrz.sys.funclib.bitctrl.modell.*;
import de.bsvrz.sys.funclib.bitctrl.modell.annotation.*;
import de.bsvrz.sys.funclib.bitctrl.modell.att.*;
import de.bsvrz.sys.funclib.bitctrl.modell.impl.*;

/**
Algorithmus-Typ.
<p>
&lt;absatz&gt;
						Algorithmus, Art der Berechnung (Steuerlogik).
					&lt;&#47;absatz&gt;
</p>
* @author BitCtrl Systems GmbH, M2T
 * @version Gültig seit KB-Version 1
 */
public class AttNbaAlgorithmus extends Zahl<		Byte
> {
	
	private static final long serialVersionUID = 1L;
	
	
	/**
	
	<p>
	
	</p>
	*/
	public static final AttNbaAlgorithmus ZUSTAND_0_NICHT_DEFINIERT = new AttNbaAlgorithmus("nicht definiert", 		Byte
	.valueOf("0"));

	/**
	
	<p>
	
	</p>
	*/
	public static final AttNbaAlgorithmus ZUSTAND_1_ALGORITHMUS_1 = new AttNbaAlgorithmus("Algorithmus 1", 		Byte
	.valueOf("1"));

	/**
	
	<p>
	
	</p>
	*/
	public static final AttNbaAlgorithmus ZUSTAND_2_ALGORITHMUS_2 = new AttNbaAlgorithmus("Algorithmus 2", 		Byte
	.valueOf("2"));

	/**
	
	<p>
	
	</p>
	*/
	public static final AttNbaAlgorithmus ZUSTAND_3_ALGORITHMUS_3 = new AttNbaAlgorithmus("Algorithmus 3", 		Byte
	.valueOf("3"));

	/**
	
	<p>
	
	</p>
	*/
	public static final AttNbaAlgorithmus ZUSTAND_4_ALGORITHMUS_4 = new AttNbaAlgorithmus("Algorithmus 4", 		Byte
	.valueOf("4"));

	/**
	
	<p>
	
	</p>
	*/
	public static final AttNbaAlgorithmus ZUSTAND_5_ALGORITHMUS_5 = new AttNbaAlgorithmus("Algorithmus 5", 		Byte
	.valueOf("5"));

	/**
	
	<p>
	
	</p>
	*/
	public static final AttNbaAlgorithmus ZUSTAND_6_ALGORITHMUS_6 = new AttNbaAlgorithmus("Algorithmus 6", 		Byte
	.valueOf("6"));

	/**
	
	<p>
	
	</p>
	*/
	public static final AttNbaAlgorithmus ZUSTAND_7_ALGORITHMUS_7 = new AttNbaAlgorithmus("Algorithmus 7", 		Byte
	.valueOf("7"));

	/**
	 * Gibt den Zustand zu einer Zahl zurück oder <code>null</code>, wenn die
	 * Zahl keinen Zustand repräsentiert.
	 *
	 * @param value ein Zahlenwert
	 * @return der Zustand zu dem Zahlenwert oder <code>null</code>, wenn die
	 * Zahl keine Entsprechnung als Zustand besitzt.
	 */
	public static AttNbaAlgorithmus getZustand(final 		Byte
	 value) {
		for (AttNbaAlgorithmus e : getZustaende()) {
			if (e.getValue().equals(value)) {
				return e;
			}
		}
		return null;
	}
	
	/**
	 * Gibt den Zustand zu einem Zustandsnamen zurück oder <code>null</code>,
	 * wenn kein Zustand einen solchen Namen hat.
	 * 
	 * @param value
	 *            der Zustandsname
	 * @return der Zustand zu dem Zustandsnamen oder <code>null</code>, wenn
	 *         kein Zustand einen solchen Namen hat.
	 */
	public static AttNbaAlgorithmus getZustand(final String value) {
		for (AttNbaAlgorithmus e : getZustaende()) {
			if (e.toString().equals(value)) {
				return e;
			}
		}
		return null;
	}
	
	/**
	 * Gibt alle Zustände zurück, die das Attribut besitzen kann.
	 *
	 * @return alle Zustände die das Attribut annehmen kann.
	 */
	public static List<AttNbaAlgorithmus> getZustaende() {
		List<AttNbaAlgorithmus> list = new ArrayList<AttNbaAlgorithmus>();
		list.add(ZUSTAND_0_NICHT_DEFINIERT);
		list.add(ZUSTAND_1_ALGORITHMUS_1);
		list.add(ZUSTAND_2_ALGORITHMUS_2);
		list.add(ZUSTAND_3_ALGORITHMUS_3);
		list.add(ZUSTAND_4_ALGORITHMUS_4);
		list.add(ZUSTAND_5_ALGORITHMUS_5);
		list.add(ZUSTAND_6_ALGORITHMUS_6);
		list.add(ZUSTAND_7_ALGORITHMUS_7);
		return list;
	}	
	/**
	 * Erzeugte eine neues Attribut nbaAlgorithmus.
	 *
	 * @param value der Wert der Zahl.
	 */
	public AttNbaAlgorithmus(final 		Byte
	 value) {
		super(value);
	}
	
	private AttNbaAlgorithmus(final String zustand, final 		Byte
	 value) {
		super(zustand, value);
	}
	
}
