/*
 * Java-Modell des Datenkatalogs.
 * Copyright (C) 2016 BitCtrl Systems GmbH 
 * 
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for more
 * details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA.
 *
 * Contact Information:
 * BitCtrl Systems GmbH
 * Weißenfelser Straße 67
 * 04229 Leipzig
 * Phone: +49 341-490670
 * mailto: info@bitctrl.de
 */

package de.bsvrz.sys.funclib.bitctrl.modell.tmumfelddatenglobal.attribute;

import java.util.*;

import com.bitctrl.beans.*;

import de.bsvrz.dav.daf.main.*;
import de.bsvrz.dav.daf.main.config.*;
import de.bsvrz.sys.funclib.bitctrl.modell.*;
import de.bsvrz.sys.funclib.bitctrl.modell.annotation.*;
import de.bsvrz.sys.funclib.bitctrl.modell.att.*;
import de.bsvrz.sys.funclib.bitctrl.modell.impl.*;

/**
Taupunkttemperatur.
<p>
Taupunkttemperatur ist diejenige Temperatur, bei der die in der Umgebungsluft der Messstelle (am Ort der Temperatur und Feuchte-Sensorik) befindliche Feuchte zu kondensieren beginnt. Die Taupunkttemperatur ist aus der Temperatur und der relativen Feuchte der Luft zu bestimmen. Zur Bestimmung ist die in den neuesten ?betriebstechnischen Anforderungen für Glättemeldeanlagen? enthaltene Berechnungsvorschrift zu verwenden. Dieser Berechnungsvorschrift liegen auch die im Wetterdienst verwendeten Taupunkttabellen zugrunde.
</p>
* @author BitCtrl Systems GmbH, M2T
 * @version Gültig seit KB-Version 1
 */
@Wertebereich(
	minimum = -1000L,
	maximum = 1000L,
	skalierung = 0.1,
	einheit = "°C"
)
public class AttUfdsTaupunktTemperatur extends Zahl<		Double
> {
	
	private static final long serialVersionUID = 1L;
	
	/**
	 * Der minimale Wert des Attributs.
	 *
	 * @deprecated neu: {@link WerteBereich#getWerteBereich(Class)} und {@link #getWerteBereich()}
	 */
	@Deprecated
	public static final 		Double
	 MIN_VALUE =
			(		double
			) (		Double
			.valueOf("-1000") * 		Double
			.valueOf("0.1"));	
	
	/**
	 * Der maximale Wert des Attributs.
	 *
	 * @deprecated neu: {@link WerteBereich#getWerteBereich(Class)} und {@link #getWerteBereich()}
	 */
	@Deprecated
	public static final 		Double
	 MAX_VALUE =
			(		double
			) (		Double
			.valueOf("1000") * 		Double
			.valueOf("0.1"));	
	
	/**
	 * Die Einheit.
	 *
	 * @deprecated neu: {@link WerteBereich#getWerteBereich(Class)} und {@link #getWerteBereich()}
	 */
	@Deprecated
	public static final String EINHEIT = "°C";
	
	/**
	Daten sind nicht ermittelbar (ist KEIN Fehler).
	<p>
	Wird gesetzt, wenn der entsprechende Wert nicht ermittelbar ist und kein Interpolation sinnvoll möglich ist (z.B. ist die Geschwindigkeit nicht ermittelbar, wenn kein Fahrzeug erfasst wurde).
	</p>
	*/
	public static final AttUfdsTaupunktTemperatur ZUSTAND_1001N_NICHT_ERMITTELBAR = new AttUfdsTaupunktTemperatur("nicht ermittelbar", 		Double
	.valueOf("-1001"));

	/**
	Daten sind fehlerhaft.
	<p>
	Wird gesetzt, wenn die Daten als fehlerhaft erkannt wurden.
	</p>
	*/
	public static final AttUfdsTaupunktTemperatur ZUSTAND_1002N_FEHLERHAFT = new AttUfdsTaupunktTemperatur("fehlerhaft", 		Double
	.valueOf("-1002"));

	/**
	Daten nicht ermittelbar, da bereits Basiswerte fehlerhaft.
	<p>
	Wird gesetzt, wenn Daten, die zur Berechnung dieses Werts notwendig sind, bereits als fehlerhaft gekennzeichnet sind, oder wenn die Berechnung aus anderen Gründen (z.B. Nenner = 0 in der Berechnungsformel) nicht möglich war.
	</p>
	*/
	public static final AttUfdsTaupunktTemperatur ZUSTAND_1003N_NICHT_ERMITTELBAR_FEHLERHAFT = new AttUfdsTaupunktTemperatur("nicht ermittelbar/fehlerhaft", 		Double
	.valueOf("-1003"));

	/**
	 * Gibt den Zustand zu einer Zahl zurück oder <code>null</code>, wenn die
	 * Zahl keinen Zustand repräsentiert.
	 *
	 * @param value ein Zahlenwert
	 * @return der Zustand zu dem Zahlenwert oder <code>null</code>, wenn die
	 * Zahl keine Entsprechnung als Zustand besitzt.
	 */
	public static AttUfdsTaupunktTemperatur getZustand(final 		Double
	 value) {
		for (AttUfdsTaupunktTemperatur e : getZustaende()) {
			if (e.getValue().equals(value)) {
				return e;
			}
		}
		return null;
	}
	
	/**
	 * Gibt den Zustand zu einem Zustandsnamen zurück oder <code>null</code>,
	 * wenn kein Zustand einen solchen Namen hat.
	 * 
	 * @param value
	 *            der Zustandsname
	 * @return der Zustand zu dem Zustandsnamen oder <code>null</code>, wenn
	 *         kein Zustand einen solchen Namen hat.
	 */
	public static AttUfdsTaupunktTemperatur getZustand(final String value) {
		for (AttUfdsTaupunktTemperatur e : getZustaende()) {
			if (e.toString().equals(value)) {
				return e;
			}
		}
		return null;
	}
	
	/**
	 * Gibt alle Zustände zurück, die das Attribut besitzen kann.
	 *
	 * @return alle Zustände die das Attribut annehmen kann.
	 */
	public static List<AttUfdsTaupunktTemperatur> getZustaende() {
		List<AttUfdsTaupunktTemperatur> list = new ArrayList<AttUfdsTaupunktTemperatur>();
		list.add(ZUSTAND_1001N_NICHT_ERMITTELBAR);
		list.add(ZUSTAND_1002N_FEHLERHAFT);
		list.add(ZUSTAND_1003N_NICHT_ERMITTELBAR_FEHLERHAFT);
		return list;
	}	
	/**
	 * Erzeugte eine neues Attribut UfdsTaupunktTemperatur.
	 *
	 * @param value der Wert der Zahl.
	 */
	public AttUfdsTaupunktTemperatur(final 		Double
	 value) {
		super(value);
	}
	
	private AttUfdsTaupunktTemperatur(final String zustand, final 		Double
	 value) {
		super(zustand, value);
	}
	
}
